struct GenCdf {
humid_base: Box<[(f32, f32)]>,
temp_base: Box<[(f32, f32)]>,
chaos: Box<[(f32, f32)]>,
alt: Box<[f64]>,
basement: Box<[f64]>,
water_alt: Box<[f32]>,
dh: Box<[isize]>,
flux: Box<[f64]>,
pure_flux: Box<[(f32, f64)]>,
alt_no_water: Box<[(f32, f32)]>,
rivers: Box<[RiverData]>,
}Expand description
A structure that holds cached noise values and cumulative distribution functions for the input that led to those values. See the definition of InverseCdf for a description of how to interpret the types of its fields.
Fields
humid_base: Box<[(f32, f32)]>temp_base: Box<[(f32, f32)]>chaos: Box<[(f32, f32)]>alt: Box<[f64]>basement: Box<[f64]>water_alt: Box<[f32]>dh: Box<[isize]>flux: Box<[f64]>NOTE: Until we hit 4096 × 4096, this should suffice since integers with an absolute value under 2^24 can be exactly represented in an f32.
pure_flux: Box<[(f32, f64)]>alt_no_water: Box<[(f32, f32)]>rivers: Box<[RiverData]>Auto Trait Implementations
impl Freeze for GenCdf
impl RefUnwindSafe for GenCdf
impl Send for GenCdf
impl Sync for GenCdf
impl Unpin for GenCdf
impl UnsafeUnpin for GenCdf
impl UnwindSafe for GenCdf